/* element.h - Message Element Format implementation
 *
 * Copyright (C) 2002,2003,2004,2005 Thomas Vander Stichele
 *               <thomas at apestaart dot org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LIBUECP_ELEMENT_H
#define LIBUECP_ELEMENT_H

/* enum for Data Set Number */
typedef enum
{
	UECP_DSN_CURRENT = 0,
	UECP_DSN_ALL_BUT_CURRENT = 254,
	UECP_DSN_ALL = 255
} UecpDataSetNumber;

typedef struct _UecpElement UecpElement;

/* we use ints for some of the struct variables so that we can use
 *  * -1 to indicate "don't use this value" */
struct _UecpElement
{
	unsigned char           message_element_code;
	UecpDataSetNumber       data_set_number;
	int                     program_service_number;
	int                     message_element_length;
	int                     message_element_data_length;
	unsigned char           *message_element_data;
};

UecpElement *	uecp_element_new		();
void		uecp_element_reset		(UecpElement *element);
void		uecp_element_dispose		(UecpElement *element);

gboolean	uecp_element_set		(UecpElement *element,
						 unsigned char mec,
						 int dsn, int psn, int mel,
						 int medl, unsigned char *med);
unsigned int	uecp_element_get_length		(UecpElement *element);
void		uecp_element_debug		(UecpElement *element);
void            uecp_element_render_to_block    (UecpElement *element,
                                                 unsigned char *block);

#endif /* LIBUECP_ELEMENT_H */

