package UECP::Messager;

use vars qw($VERSION);

$UECP::Messager::VERSION = "0.01";

use strict;

use UECP;

=head1 NAME

UECP::Messager - OO interface to libuecp

=head1 SYNOPSIS

    use UECP::Messager;

    $messager = new UECP::Messager ();
    $block = $messager->ta_tp(1, 1);
    $block = $messager->ps("4FM");

=head1 DESCRIPTION

This module provides an interface to libuecp, a library that implements
the UECP protocol for binary communication with RDS encoders.

=head1 CONSTRUCTOR

=over 4

=item new ()

Creates a new UECP::Messager.

=back

=head1 METHODS

=over 4

=item ta_tp ( BOOLEAN, BOOLEAN )
Returns a binary message to signal Traffic Programming and 
Traffic Announcement.

=item ps ( STRING )
Returns a binary message to signal PS information (max. 8 chars long)
ck

=head1 BUGS

Probably.

=head1 AUTHOR

Thomas Vander Stichele thomas (at) apestaart (dot) org

Copyright (c) 2003,2004,2005 Thomas Vander Stichele.  All rights reserved.

=head1 VERSION

Version 0.01 (10 January 2003)

=head1 HISTORY

=over 4

=item Version 0.01

Start.

=back

=cut

#
# new ()
#

sub new ($)
{
  my $proto = shift;
  my $class = ref ($proto) || $proto;
  my $self = {};
  bless ($self, $class);
  $self->{messager} = UECP::messager_new ();
  return $self;
}

sub reset ($)
{
  my ($self) = @_;
  return UECP::messager_reset ($self->{messager});  
}

#
# setters
#

sub set_site_address ($$)
{
  my ($self, $address) = @_;
  return UECP::messager_set_site_address ($self->{messager}, $address);
}

sub set_encoder_address ($$)
{
  my ($self, $address) = @_;
  return UECP::messager_set_encoder_address ($self->{messager}, $address);
}

sub set_sequence_counter ($$)
{
  my ($self, $sqc) = @_;
  return UECP::messager_set_sequence_counter ($self->{messager}, $sqc);
}

sub set_data_set_number ($$)
{
  my ($self, $number) = @_;
  return UECP::messager_set_data_set_number ($self->{messager}, $number);
}

sub set_program_service_number ($$)
{
  my ($self, $number) = @_;
  return UECP::messager_set_program_service_number ($self->{messager}, $number);
}

#
# specific RDS functions
#
sub ps ($$)
{
  my ($self, $ps) = @_;
  return UECP::messager_ps ($self->{messager}, $ps);
}

sub ta_tp ($$$)
{
  my ($self, $ta, $tp) = @_;
  return UECP::messager_ta_tp ($self->{messager}, $ta, $tp);
}

# send radiotext;
# first arg: text to send
# second: whether or not to add it to rt buffer
# third: number of repeats (1-15), 0 for infinite
# fourth: whether or not to toggle A/B flag

sub rt ($$$$$)
{
  my $self = shift @_;
  my $text = shift @_;
  my $add = shift @_ || 0;
  my $number = shift @_ || 0;
  my $toggle = shift @_ || 0;

  return UECP::messager_rt ($self->{messager}, $text, $add, $number, $toggle);
}
# FIXME: where is the destructor for the object ?
