/* test-crc.c - tests for the crc function
 *
 * Copyright (C) 2002,2003,2004,2005 Thomas Vander Stichele
 *               <thomas at apestaart dot org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>

#include <glib.h>

extern guint16 ccitt_crc (const unsigned char *ptr, register int len);

static int
check_crc (const char *string, guint16 expected)
{
	guint16 crc;

	crc = ccitt_crc ((unsigned char *) string, strlen (string));
	g_print ("crc of %s: %x\n", string, crc);
	if (crc != expected)
	{
		g_print ("Expected %x, error !\n", expected);
		return -1;
	}
	return 0;
}

int
main (int argc, char *argv[])
{
	/* THE */
	if (check_crc ("THE", 0x2d69) != 0) return -1;

	/* CatMouse987654321 */
	if (check_crc ("CatMouse987654321", 0xdd45) != 0) return -1;

	/* this string is in the uecp specification;
	 * the protocol used is the same except for a final xor,
	 * as shown here */
	/* 2D111234010105ABCD123F0XXXX11069212491000320066 */
	if (check_crc ("2D111234010105ABCD123F0XXXX11069212491000320066",
		       0x9723) != 0) return -1;

	return 0;
}
